[asterisk-commits] kmoore: branch kmoore/event_system_strip r395393 - in /team/kmoore/event_syst...
SVN commits to the Asterisk project
asterisk-commits at lists.digium.com
Thu Jul 25 08:07:29 CDT 2013
Author: kmoore
Date: Thu Jul 25 08:07:28 2013
New Revision: 395393
URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=395393
Log:
Rip out some unused IEs
Modified:
team/kmoore/event_system_strip/include/asterisk/event_defs.h
team/kmoore/event_system_strip/main/event.c
team/kmoore/event_system_strip/main/security_events.c
team/kmoore/event_system_strip/res/res_security_log.c
team/kmoore/event_system_strip/tests/test_event.c
Modified: team/kmoore/event_system_strip/include/asterisk/event_defs.h
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/event_system_strip/include/asterisk/event_defs.h?view=diff&rev=395393&r1=395392&r2=395393
==============================================================================
--- team/kmoore/event_system_strip/include/asterisk/event_defs.h (original)
+++ team/kmoore/event_system_strip/include/asterisk/event_defs.h Thu Jul 25 08:07:28 2013
@@ -50,24 +50,6 @@
AST_EVENT_IE_END = -1,
/*!
- * \brief Number of new messages
- * Used by: AST_EVENT_MWI
- * Payload type: UINT
- */
- AST_EVENT_IE_NEWMSGS = 0x0001,
- /*!
- * \brief Number of
- * Used by: AST_EVENT_MWI
- * Payload type: UINT
- */
- AST_EVENT_IE_OLDMSGS = 0x0002,
- /*!
- * \brief Mailbox name \verbatim (mailbox[@context]) \endverbatim
- * Used by: AST_EVENT_MWI
- * Payload type: STR
- */
- AST_EVENT_IE_MAILBOX = 0x0003,
- /*!
* \brief Unique ID
* Used by: AST_EVENT_SUB, AST_EVENT_UNSUB
* Payload type: UINT
@@ -250,7 +232,6 @@
* This IE indicates which server the event originated from
*/
AST_EVENT_IE_EID = 0x0021,
- AST_EVENT_IE_SECURITY_EVENT = 0x0022,
AST_EVENT_IE_EVENT_VERSION = 0x0023,
AST_EVENT_IE_SERVICE = 0x0024,
AST_EVENT_IE_MODULE = 0x0025,
@@ -273,17 +254,7 @@
AST_EVENT_IE_RECEIVED_HASH = 0x0036,
AST_EVENT_IE_USING_PASSWORD = 0x0037,
AST_EVENT_IE_ATTEMPTED_TRANSPORT = 0x0038,
- AST_EVENT_IE_PRESENCE_PROVIDER = 0x0039,
- AST_EVENT_IE_PRESENCE_STATE = 0x003a,
- AST_EVENT_IE_PRESENCE_SUBTYPE = 0x003b,
- AST_EVENT_IE_PRESENCE_MESSAGE = 0x003c,
-
- /*!
- * \brief Event non-cachability flag
- * Used by: All events
- * Payload type: UINT
- */
- AST_EVENT_IE_CACHABLE = 0x003d,
+
/*! \brief Must be the last IE value +1 */
AST_EVENT_IE_TOTAL = 0x003e,
};
Modified: team/kmoore/event_system_strip/main/event.c
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/event_system_strip/main/event.c?view=diff&rev=395393&r1=395392&r2=395393
==============================================================================
--- team/kmoore/event_system_strip/main/event.c (original)
+++ team/kmoore/event_system_strip/main/event.c Thu Jul 25 08:07:28 2013
@@ -143,9 +143,6 @@
* \brief IE payload types and names
*/
static const struct ie_map ie_maps[AST_EVENT_IE_TOTAL] = {
- [AST_EVENT_IE_NEWMSGS] = { AST_EVENT_IE_PLTYPE_UINT, "NewMessages" },
- [AST_EVENT_IE_OLDMSGS] = { AST_EVENT_IE_PLTYPE_UINT, "OldMessages" },
- [AST_EVENT_IE_MAILBOX] = { AST_EVENT_IE_PLTYPE_STR, "Mailbox" },
[AST_EVENT_IE_UNIQUEID] = { AST_EVENT_IE_PLTYPE_UINT, "UniqueID" },
[AST_EVENT_IE_EVENTTYPE] = { AST_EVENT_IE_PLTYPE_UINT, "EventType" },
[AST_EVENT_IE_EXISTS] = { AST_EVENT_IE_PLTYPE_UINT, "Exists" },
@@ -175,7 +172,6 @@
[AST_EVENT_IE_CEL_LINKEDID] = { AST_EVENT_IE_PLTYPE_STR, "CELLinkedID" },
[AST_EVENT_IE_CEL_PEERACCT] = { AST_EVENT_IE_PLTYPE_STR, "CELPeerAcct" },
[AST_EVENT_IE_CEL_EXTRA] = { AST_EVENT_IE_PLTYPE_STR, "CELExtra" },
- [AST_EVENT_IE_SECURITY_EVENT] = { AST_EVENT_IE_PLTYPE_STR, "SecurityEvent" },
[AST_EVENT_IE_EVENT_VERSION] = { AST_EVENT_IE_PLTYPE_UINT, "EventVersion" },
[AST_EVENT_IE_SERVICE] = { AST_EVENT_IE_PLTYPE_STR, "Service" },
[AST_EVENT_IE_MODULE] = { AST_EVENT_IE_PLTYPE_STR, "Module" },
@@ -198,11 +194,6 @@
[AST_EVENT_IE_RECEIVED_HASH] = { AST_EVENT_IE_PLTYPE_STR, "ReceivedHash" },
[AST_EVENT_IE_USING_PASSWORD] = { AST_EVENT_IE_PLTYPE_UINT, "UsingPassword" },
[AST_EVENT_IE_ATTEMPTED_TRANSPORT] = { AST_EVENT_IE_PLTYPE_STR, "AttemptedTransport" },
- [AST_EVENT_IE_CACHABLE] = { AST_EVENT_IE_PLTYPE_UINT, "Cachable" },
- [AST_EVENT_IE_PRESENCE_PROVIDER] = { AST_EVENT_IE_PLTYPE_STR, "PresenceProvider" },
- [AST_EVENT_IE_PRESENCE_STATE] = { AST_EVENT_IE_PLTYPE_UINT, "PresenceState" },
- [AST_EVENT_IE_PRESENCE_SUBTYPE] = { AST_EVENT_IE_PLTYPE_STR, "PresenceSubtype" },
- [AST_EVENT_IE_PRESENCE_MESSAGE] = { AST_EVENT_IE_PLTYPE_STR, "PresenceMessage" },
};
const char *ast_event_get_type_name(const struct ast_event *event)
Modified: team/kmoore/event_system_strip/main/security_events.c
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/event_system_strip/main/security_events.c?view=diff&rev=395393&r1=395392&r2=395393
==============================================================================
--- team/kmoore/event_system_strip/main/security_events.c (original)
+++ team/kmoore/event_system_strip/main/security_events.c Thu Jul 25 08:07:28 2013
@@ -657,13 +657,11 @@
* This is true even if ast_json_object_set fails.
*/
- /* AST_EVENT_IE_SECURITY_EVENT */
json_temp = ast_json_integer_create(sec->event_type);
- if (!json_temp || ast_json_object_set(json_object, ast_event_get_ie_type_name(AST_EVENT_IE_SECURITY_EVENT), json_temp)) {
- return NULL;
- }
-
- /* AST_EVENT_IE_EVENT_VERSION */
+ if (!json_temp || ast_json_object_set(json_object, "SecurityEvent", json_temp)) {
+ return NULL;
+ }
+
json_temp = ast_json_stringf("%d", sec->version);
if (!json_temp || ast_json_object_set(json_object, ast_event_get_ie_type_name(AST_EVENT_IE_EVENT_VERSION), json_temp)) {
return NULL;
Modified: team/kmoore/event_system_strip/res/res_security_log.c
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/event_system_strip/res/res_security_log.c?view=diff&rev=395393&r1=395392&r2=395393
==============================================================================
--- team/kmoore/event_system_strip/res/res_security_log.c (original)
+++ team/kmoore/event_system_strip/res/res_security_log.c Thu Jul 25 08:07:28 2013
@@ -105,8 +105,7 @@
return;
}
- ast_str_set(&str, 0, "%s=\"%s\"",
- ast_event_get_ie_type_name(AST_EVENT_IE_SECURITY_EVENT),
+ ast_str_set(&str, 0, "SecurityEvent=\"%s\"",
ast_security_event_get_name(event_type));
append_json(&str, json,
Modified: team/kmoore/event_system_strip/tests/test_event.c
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/event_system_strip/tests/test_event.c?view=diff&rev=395393&r1=395392&r2=395393
==============================================================================
--- team/kmoore/event_system_strip/tests/test_event.c (original)
+++ team/kmoore/event_system_strip/tests/test_event.c Thu Jul 25 08:07:28 2013
@@ -82,19 +82,19 @@
}
/* Check #4: Check for the string IE */
- if (strcmp(str, ast_event_get_ie_str(event, AST_EVENT_IE_MAILBOX))) {
+ if (strcmp(str, ast_event_get_ie_str(event, AST_EVENT_IE_CEL_USEREVENT_NAME))) {
ast_test_status_update(test, "Failed to get string IE.\n");
return -1;
}
/* Check #5: Check for the uint IE */
- if (uint != ast_event_get_ie_uint(event, AST_EVENT_IE_NEWMSGS)) {
+ if (uint != ast_event_get_ie_uint(event, AST_EVENT_IE_CEL_AMAFLAGS)) {
ast_test_status_update(test, "Failed to get uint IE.\n");
return -1;
}
/* Check #6: Check for the bitflags IE */
- if (bitflags != ast_event_get_ie_bitflags(event, AST_EVENT_IE_OLDMSGS)) {
+ if (bitflags != ast_event_get_ie_bitflags(event, AST_EVENT_IE_UNIQUEID)) {
ast_test_status_update(test, "Failed to get bitflags IE.\n");
return -1;
}
@@ -107,7 +107,7 @@
/* Check #8: Check if a check for a uint IE that isn't there returns 0 */
if (ast_event_get_ie_uint(event, AST_EVENT_IE_STATE)) {
- ast_test_status_update(test, "OLDMSGS IE should be 0\n");
+ ast_test_status_update(test, "UNIQUEID IE should be 0\n");
return -1;
}
@@ -157,19 +157,19 @@
goto return_cleanup;
}
- if (ast_event_append_ie_str(&event, AST_EVENT_IE_MAILBOX, str)) {
+ if (ast_event_append_ie_str(&event, AST_EVENT_IE_CEL_USEREVENT_NAME, str)) {
ast_test_status_update(test, "Failed to append str IE\n");
res = AST_TEST_FAIL;
goto return_cleanup;
}
- if (ast_event_append_ie_uint(&event, AST_EVENT_IE_NEWMSGS, uint)) {
+ if (ast_event_append_ie_uint(&event, AST_EVENT_IE_CEL_AMAFLAGS, uint)) {
ast_test_status_update(test, "Failed to append uint IE\n");
res = AST_TEST_FAIL;
goto return_cleanup;
}
- if (ast_event_append_ie_bitflags(&event, AST_EVENT_IE_OLDMSGS, bitflags)) {
+ if (ast_event_append_ie_bitflags(&event, AST_EVENT_IE_UNIQUEID, bitflags)) {
ast_test_status_update(test, "Failed to append bitflags IE\n");
res = AST_TEST_FAIL;
goto return_cleanup;
@@ -182,9 +182,9 @@
}
event2 = ast_event_new(type,
- AST_EVENT_IE_MAILBOX, AST_EVENT_IE_PLTYPE_STR, str,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_UINT, uint,
- AST_EVENT_IE_OLDMSGS, AST_EVENT_IE_PLTYPE_BITFLAGS, bitflags,
+ AST_EVENT_IE_CEL_USEREVENT_NAME, AST_EVENT_IE_PLTYPE_STR, str,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_UINT, uint,
+ AST_EVENT_IE_UNIQUEID, AST_EVENT_IE_PLTYPE_BITFLAGS, bitflags,
AST_EVENT_IE_END);
if (!event2) {
@@ -405,12 +405,12 @@
/*
* Subscription TEST_SUBS_CUSTOM_RAW:
* - allocate normally
* - subscribe to CUSTOM events with a MAILBOX RAW IE check
*/
ast_test_status_update(test, "Adding TEST_SUBS_CUSTOM_RAW subscription\n");
test_subs[TEST_SUBS_CUSTOM_RAW].sub = ast_event_subscribe(AST_EVENT_CUSTOM, event_sub_cb,
test_subs_class_type_str(TEST_SUBS_CUSTOM_RAW), &test_subs[TEST_SUBS_CUSTOM_RAW].data,
- AST_EVENT_IE_MAILBOX, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar"),
+ AST_EVENT_IE_CEL_USEREVENT_NAME, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar"),
AST_EVENT_IE_END);
if (!test_subs[TEST_SUBS_CUSTOM_RAW].sub) {
ast_test_status_update(test, "Failed to create TEST_SUBS_CUSTOM_RAW subscription\n");
@@ -429,12 +429,12 @@
/*
* Subscription TEST_SUBS_CUSTOM_UINT:
* - allocate normally
* - subscribe to CUSTOM events with a NEWMSGS UINT IE check
*/
ast_test_status_update(test, "Adding TEST_SUBS_CUSTOM_UINT subscription\n");
test_subs[TEST_SUBS_CUSTOM_UINT].sub = ast_event_subscribe(AST_EVENT_CUSTOM, event_sub_cb,
test_subs_class_type_str(TEST_SUBS_CUSTOM_UINT), &test_subs[TEST_SUBS_CUSTOM_UINT].data,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_UINT, 5,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_UINT, 5,
AST_EVENT_IE_END);
if (!test_subs[TEST_SUBS_CUSTOM_UINT].sub) {
ast_test_status_update(test, "Failed to create TEST_SUBS_CUSTOM_UINT subscription\n");
@@ -453,12 +453,12 @@
/*
* Subscription TEST_SUBS_CUSTOM_BITFLAGS:
* - allocate normally
* - subscribe to CUSTOM events with a NEWMSGS BITFLAGS IE check
*/
ast_test_status_update(test, "Adding TEST_SUBS_CUSTOM_BITFLAGS subscription\n");
test_subs[TEST_SUBS_CUSTOM_BITFLAGS].sub = ast_event_subscribe(AST_EVENT_CUSTOM, event_sub_cb,
test_subs_class_type_str(TEST_SUBS_CUSTOM_BITFLAGS), &test_subs[TEST_SUBS_CUSTOM_BITFLAGS].data,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_BITFLAGS, 0x06,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_BITFLAGS, 0x06,
AST_EVENT_IE_END);
if (!test_subs[TEST_SUBS_CUSTOM_BITFLAGS].sub) {
ast_test_status_update(test, "Failed to create TEST_SUBS_CUSTOM_BITFLAGS subscription\n");
@@ -477,13 +477,13 @@
/*
* Subscription TEST_SUBS_CUSTOM_EXISTS:
* - allocate normally
* - subscribe to CUSTOM events with a NEWMSGS UINT and OLDMSGS EXISTS IE check
*/
ast_test_status_update(test, "Adding TEST_SUBS_CUSTOM_EXISTS subscription\n");
test_subs[TEST_SUBS_CUSTOM_EXISTS].sub = ast_event_subscribe(AST_EVENT_CUSTOM, event_sub_cb,
test_subs_class_type_str(TEST_SUBS_CUSTOM_EXISTS), &test_subs[TEST_SUBS_CUSTOM_EXISTS].data,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_UINT, 4,
- AST_EVENT_IE_OLDMSGS, AST_EVENT_IE_PLTYPE_EXISTS,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_UINT, 4,
+ AST_EVENT_IE_UNIQUEID, AST_EVENT_IE_PLTYPE_EXISTS,
AST_EVENT_IE_END);
if (!test_subs[TEST_SUBS_CUSTOM_EXISTS].sub) {
ast_test_status_update(test, "Failed to create TEST_SUBS_CUSTOM_EXISTS subscription\n");
@@ -534,7 +534,7 @@
goto return_cleanup;
}
- if (ast_event_sub_append_ie_uint(test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub, AST_EVENT_IE_NEWMSGS, 4)) {
+ if (ast_event_sub_append_ie_uint(test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub, AST_EVENT_IE_CEL_AMAFLAGS, 4)) {
ast_event_sub_destroy(test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub);
test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub = NULL;
ast_test_status_update(test, "Failed to append UINT IE to TEST_SUBS_CUSTOM_DYNAMIC subscription\n");
@@ -542,7 +542,7 @@
goto return_cleanup;
}
- if (ast_event_sub_append_ie_bitflags(test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub, AST_EVENT_IE_OLDMSGS, 1)) {
+ if (ast_event_sub_append_ie_bitflags(test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub, AST_EVENT_IE_UNIQUEID, 1)) {
ast_event_sub_destroy(test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub);
test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub = NULL;
ast_test_status_update(test, "Failed to append BITFLAGS IE to TEST_SUBS_CUSTOM_DYNAMIC subscription\n");
@@ -558,7 +558,7 @@
goto return_cleanup;
}
- if (ast_event_sub_append_ie_raw(test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub, AST_EVENT_IE_MAILBOX, "800 km",
+ if (ast_event_sub_append_ie_raw(test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub, AST_EVENT_IE_CEL_USEREVENT_NAME, "800 km",
strlen("800 km"))) {
ast_event_sub_destroy(test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub);
test_subs[TEST_SUBS_CUSTOM_DYNAMIC].sub = NULL;
@@ -627,7 +627,7 @@
/* Check RAW matching. */
sub_res = ast_event_check_subscriber(AST_EVENT_CUSTOM,
- AST_EVENT_IE_MAILBOX, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar"),
+ AST_EVENT_IE_CEL_USEREVENT_NAME, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar"),
AST_EVENT_IE_END);
if (sub_res != AST_EVENT_SUB_EXISTS) {
ast_test_status_update(test, "Raw FOO/bar subscription did not exist\n");
@@ -635,7 +635,7 @@
}
sub_res = ast_event_check_subscriber(AST_EVENT_CUSTOM,
- AST_EVENT_IE_MAILBOX, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar") - 1,
+ AST_EVENT_IE_CEL_USEREVENT_NAME, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar") - 1,
AST_EVENT_IE_END);
if (sub_res != AST_EVENT_SUB_NONE) {
ast_test_status_update(test, "Raw FOO/bar-1 subscription should not exist! (%d)\n",
@@ -644,7 +644,7 @@
}
sub_res = ast_event_check_subscriber(AST_EVENT_CUSTOM,
- AST_EVENT_IE_MAILBOX, AST_EVENT_IE_PLTYPE_RAW, "Monkeys", sizeof("Monkeys"),
+ AST_EVENT_IE_CEL_USEREVENT_NAME, AST_EVENT_IE_PLTYPE_RAW, "Monkeys", sizeof("Monkeys"),
AST_EVENT_IE_END);
if (sub_res != AST_EVENT_SUB_NONE) {
ast_test_status_update(test, "Raw Monkeys subscription should not exist! (%d)\n",
@@ -654,7 +654,7 @@
/* Check UINT matching. */
sub_res = ast_event_check_subscriber(AST_EVENT_CUSTOM,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_UINT, 5,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_UINT, 5,
AST_EVENT_IE_END);
if (sub_res != AST_EVENT_SUB_EXISTS) {
ast_test_status_update(test, "UINT=5 subscription did not exist\n");
@@ -662,7 +662,7 @@
}
sub_res = ast_event_check_subscriber(AST_EVENT_CUSTOM,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_UINT, 1,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_UINT, 1,
AST_EVENT_IE_END);
if (sub_res != AST_EVENT_SUB_NONE) {
ast_test_status_update(test, "UINT=1 subscription should not exist! (%d)\n",
@@ -672,7 +672,7 @@
/* Check BITFLAGS matching. */
sub_res = ast_event_check_subscriber(AST_EVENT_CUSTOM,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_BITFLAGS, 2,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_BITFLAGS, 2,
AST_EVENT_IE_END);
if (sub_res != AST_EVENT_SUB_EXISTS) {
ast_test_status_update(test, "BITFLAGS=2 subscription did not exist\n");
@@ -680,7 +680,7 @@
}
sub_res = ast_event_check_subscriber(AST_EVENT_CUSTOM,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_BITFLAGS, 8,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_BITFLAGS, 8,
AST_EVENT_IE_END);
if (sub_res != AST_EVENT_SUB_NONE) {
ast_test_status_update(test, "BITFLAGS=8 subscription should not exist! (%d)\n",
@@ -690,8 +690,8 @@
/* Check EXISTS matching. */
sub_res = ast_event_check_subscriber(AST_EVENT_CUSTOM,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_UINT, 4,
- AST_EVENT_IE_OLDMSGS, AST_EVENT_IE_PLTYPE_UINT, 100,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_UINT, 4,
+ AST_EVENT_IE_UNIQUEID, AST_EVENT_IE_PLTYPE_UINT, 100,
AST_EVENT_IE_END);
if (sub_res != AST_EVENT_SUB_EXISTS) {
ast_test_status_update(test, "EXISTS subscription did not exist\n");
@@ -699,7 +699,7 @@
}
sub_res = ast_event_check_subscriber(AST_EVENT_CUSTOM,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_UINT, 4,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_UINT, 4,
AST_EVENT_IE_END);
if (sub_res != AST_EVENT_SUB_NONE) {
ast_test_status_update(test, "EXISTS subscription should not exist! (%d)\n",
@@ -717,7 +717,7 @@
*/
event = ast_event_new(AST_EVENT_CUSTOM,
AST_EVENT_IE_DEVICE, AST_EVENT_IE_PLTYPE_STR, "Mula",
- AST_EVENT_IE_MAILBOX, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar"),
+ AST_EVENT_IE_CEL_USEREVENT_NAME, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar"),
AST_EVENT_IE_END);
if (!event) {
ast_test_status_update(test, "Failed to create event\n");
@@ -772,7 +772,7 @@
* TEST_SUBS_CUSTOM_ANY
*/
event = ast_event_new(AST_EVENT_CUSTOM,
- AST_EVENT_IE_MAILBOX, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar") - 1,
+ AST_EVENT_IE_CEL_USEREVENT_NAME, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar") - 1,
AST_EVENT_IE_DEVICE, AST_EVENT_IE_PLTYPE_STR, "FOO/bar",
AST_EVENT_IE_END);
if (!event) {
@@ -797,7 +797,7 @@
*/
event = ast_event_new(AST_EVENT_CUSTOM,
AST_EVENT_IE_DEVICE, AST_EVENT_IE_PLTYPE_STR, "Misery",
- AST_EVENT_IE_MAILBOX, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar"),
+ AST_EVENT_IE_CEL_USEREVENT_NAME, AST_EVENT_IE_PLTYPE_RAW, "FOO/bar", sizeof("FOO/bar"),
AST_EVENT_IE_END);
if (!event) {
ast_test_status_update(test, "Failed to create event\n");
@@ -821,7 +821,7 @@
* TEST_SUBS_CUSTOM_ANY
*/
event = ast_event_new(AST_EVENT_CUSTOM,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_UINT, 5,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_UINT, 5,
AST_EVENT_IE_END);
if (!event) {
ast_test_status_update(test, "Failed to create event\n");
@@ -844,7 +844,7 @@
* TEST_SUBS_CUSTOM_ANY
*/
event = ast_event_new(AST_EVENT_CUSTOM,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_UINT, 4,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_UINT, 4,
AST_EVENT_IE_END);
if (!event) {
ast_test_status_update(test, "Failed to create event\n");
@@ -868,8 +868,8 @@
* TEST_SUBS_CUSTOM_ANY
*/
event = ast_event_new(AST_EVENT_CUSTOM,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_UINT, 4,
- AST_EVENT_IE_OLDMSGS, AST_EVENT_IE_PLTYPE_UINT, 4,
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_UINT, 4,
+ AST_EVENT_IE_UNIQUEID, AST_EVENT_IE_PLTYPE_UINT, 4,
AST_EVENT_IE_END);
if (!event) {
ast_test_status_update(test, "Failed to create event\n");
@@ -896,9 +896,9 @@
* TEST_SUBS_CUSTOM_ANY
*/
event = ast_event_new(AST_EVENT_CUSTOM,
- AST_EVENT_IE_NEWMSGS, AST_EVENT_IE_PLTYPE_UINT, 4,
- AST_EVENT_IE_OLDMSGS, AST_EVENT_IE_PLTYPE_UINT, 5,
- AST_EVENT_IE_MAILBOX, AST_EVENT_IE_PLTYPE_RAW, "800 km", strlen("800 km"),
+ AST_EVENT_IE_CEL_AMAFLAGS, AST_EVENT_IE_PLTYPE_UINT, 4,
+ AST_EVENT_IE_UNIQUEID, AST_EVENT_IE_PLTYPE_UINT, 5,
+ AST_EVENT_IE_CEL_USEREVENT_NAME, AST_EVENT_IE_PLTYPE_RAW, "800 km", strlen("800 km"),
AST_EVENT_IE_DEVICE, AST_EVENT_IE_PLTYPE_STR, "FOO/bar",
AST_EVENT_IE_STATE, AST_EVENT_IE_PLTYPE_UINT, 5,
AST_EVENT_IE_END);
@@ -405,12 +405,12 @@
* Subscription TEST_SUBS_CUSTOM_RAW:
* - allocate normally
- * - subscribe to CUSTOM events with a MAILBOX RAW IE check
+ * - subscribe to CUSTOM events with a CEL_USEREVENT_NAME RAW IE check
*/
ast_test_status_update(test, "Adding TEST_SUBS_CUSTOM_RAW subscription\n");
@@ -429,12 +429,12 @@
* Subscription TEST_SUBS_CUSTOM_UINT:
* - allocate normally
- * - subscribe to CUSTOM events with a NEWMSGS UINT IE check
+ * - subscribe to CUSTOM events with a CEL_AMAFLAGS UINT IE check
*/
ast_test_status_update(test, "Adding TEST_SUBS_CUSTOM_UINT subscription\n");
@@ -453,12 +453,12 @@
* Subscription TEST_SUBS_CUSTOM_BITFLAGS:
* - allocate normally
- * - subscribe to CUSTOM events with a NEWMSGS BITFLAGS IE check
+ * - subscribe to CUSTOM events with a CEL_AMAFLAGS BITFLAGS IE check
*/
ast_test_status_update(test, "Adding TEST_SUBS_CUSTOM_BITFLAGS subscription\n");
@@ -477,13 +477,13 @@
* Subscription TEST_SUBS_CUSTOM_EXISTS:
* - allocate normally
- * - subscribe to CUSTOM events with a NEWMSGS UINT and OLDMSGS EXISTS IE check
+ * - subscribe to CUSTOM events with a CEL_AMAFLAGS UINT and UNIQUEID EXISTS IE check
*/
ast_test_status_update(test, "Adding TEST_SUBS_CUSTOM_EXISTS subscription\n");
More information about the asterisk-commits
mailing list